%Author: Pallavi A Raiturkar
%Script to generate average bin plots for pupil diameter, according to
%Katti paper (see fig 4(b) in paper)
%
clear;
clc;
vidChoice =1;
vidName = returnVideoName(vidChoice);
[timeIndex,frameIndex] = returnFrameInfo(vidChoice);

subjectNumbers = [9 10 11 12 13 14 15 16 17 18];
numSubjects = size(subjectNumbers,2);

numberFrames = returnNumberFrames(vidChoice);
if(vidChoice == 1)
    frameRate = 24;
else
    frameRate = 30;
end
numberSecondsRemoved = 12;
numberFramesRemoved = numberSecondsRemoved * frameRate;

newNumberFrames = numberFrames - numberFramesRemoved;
binValue = zeros(newNumberFrames,numSubjects);
binValueLum = zeros(newNumberFrames,numSubjects);
meanPupil = zeros(newNumberFrames,numSubjects);
meanPupilLum = zeros(newNumberFrames,numSubjects);
frameIndex = frameIndex(numberFramesRemoved+1:end);
for i = 1:size(subjectNumbers,2)
    
    binValue(:,i) = returnBinValue(vidChoice,subjectNumbers(i),numberSecondsRemoved);
    meanPupil(:,i) = returnMeanPupil(vidChoice, subjectNumbers(i),numberSecondsRemoved);
    binValueLum(:,i) = returnBinValueLum(vidChoice, subjectNumbers(i),numberSecondsRemoved);
    meanPupilLum(:,i) = returnMeanPupilLum(vidChoice, subjectNumbers(i),numberSecondsRemoved);
    
end

meanBinValue = mean(binValue,2);
meanBinValueLum = mean(binValueLum,2);

finalMeanPupil = mean(meanPupil,2);
% finalMedianPupil = median(meanPupil,2);
finalMeanPupilLum = mean(meanPupilLum,2);
% finalMedianPupilLum = median(meanPupilLum,2);


meanValue = mean(finalMeanPupil);
stdValue = std(finalMeanPupil);
meanValueLum = mean(finalMeanPupilLum);
stdValueLum = std(finalMeanPupilLum);
binValue = fix((finalMeanPupil - meanValue)/stdValue);
binValueLum = fix((finalMeanPupilLum-meanValueLum)/stdValueLum);


figure(3);
plot(frameIndex,binValue,'b','LineWidth',2);
hold on;
plot(frameIndex,binValueLum,'m','LineWidth',2);
hold on;
xL = get(gca,'xLim');
plot(xL,[0.75 0.75],'k--','LineWidth',2);
legend('Moving Average','Low Pass');
title(vidName);
% 
figure(4);
% subplot(2,1,2);
plot(frameIndex,meanBinValue,'b','Linewidth',2);
hold on;
plot(frameIndex,meanBinValueLum,'m','Linewidth',2);

hold on;
xL = get(gca,'xlim');
plot(xL,[0.5 0.5],'k--','Linewidth',2);
% hold on;
% plot(xL,[0.25 0.25],'c--');
xlabel('Frame Number');
% ylabel('Standard Deviation');
legend('Moving Average','Low Pass');
title(vidName);

highSelectionMA = frameIndex(meanBinValue>=0.5);
highSelectionLP = frameIndex(meanBinValueLum>=0.5);
lowSelectionMA = frameIndex(meanBinValue<0.5);
lowSelectionLP = frameIndex(meanBinValueLum<0.5);

annotation = plotAnnotation(vidChoice,1);


annotationNot = setdiff(frameIndex, annotation);

truePositiveMA = size(intersect(highSelectionMA,annotation),1)
trueNegativeMA = size(intersect(lowSelectionMA,annotationNot),1)
falseNegativeMA = size(intersect(lowSelectionMA,annotation),1)
falsePositiveMA = size(intersect(highSelectionMA,annotationNot),1)
% 
% 
truePositiveLP = size(intersect(highSelectionLP,annotation),1)
trueNegativeLP = size(intersect(lowSelectionLP,annotationNot),1)
falseNegativeLP = size(intersect(lowSelectionLP,annotation),1)
falsePositiveLP = size(intersect(highSelectionLP,annotationNot),1)

TG = size(annotation,1)
TF = size(frameIndex,1)
% 
% 
% size(highSelectionMA,1)
% size(highSelectionLP,1)
